@@ -57,7 +57,11 @@ void Basic_buffer::add_line( const char * const buf, const int len )
   {
   data.back().append( buf, len );
   if( data.back().size() && data.back()[data.back().size()-1] == '\n' )
+    {
+    if( data.size() >= data.capacity() && data.size() >= 10000 )
+      data.reserve( data.size() + ( data.size() / 10 ) );
     data.push_back( std::string() );
+    }
   }
 
 
@@ -67,9 +71,9 @@ bool Basic_buffer::detect_and_remove_cr() throw()
   if( lines() <= 1 ) return false;
   for( int i = 0; i < last_line(); ++i )
     {
-    const std::string & line = data[i];
-    const int size = line.size();
-    if( size < 2 || line[size-2] != '\r' ) return false;
+    const std::string & s = data[i];
+    const int size = s.size();
+    if( size < 2 || s[size-2] != '\r' ) return false;
     }
   for( int i = 0; i < last_line(); ++i )
     data[i].erase( data[i].size() - 2, 1 );
