@@ -89,6 +89,9 @@ void show_version() throw()
   }
 
 
+extern "C" void termination_handler( int ) throw() { std::exit( 1 ); }
+
+
 int set_signal( int signum, void (*handler)(int) ) throw()
   {
   struct sigaction new_action;
@@ -102,20 +105,34 @@ int set_signal( int signum, void (*handler)(int) ) throw()
 
 void restore_signals() throw()
   {
+  set_signal( SIGALRM, SIG_DFL );
+  set_signal( SIGBUS, SIG_DFL );
+  set_signal( SIGFPE, SIG_DFL );
+  set_signal( SIGHUP, SIG_DFL );
+  set_signal( SIGILL, SIG_DFL );
   set_signal( SIGINT, SIG_DFL );
   set_signal( SIGPIPE, SIG_DFL );
-  set_signal( SIGFPE, SIG_DFL );
-  set_signal( SIGALRM, SIG_DFL );
+  set_signal( SIGSEGV, SIG_DFL );
+  set_signal( SIGTERM, SIG_DFL );
+  set_signal( SIGUSR1, SIG_DFL );
+  set_signal( SIGUSR2, SIG_DFL );
   }
 
 
 void set_signals() throw()
   {
   std::atexit( restore_signals );
+  set_signal( SIGALRM, Screen::clock_handler );
+  set_signal( SIGBUS, termination_handler );
+  set_signal( SIGFPE, SIG_IGN );
+  set_signal( SIGHUP, termination_handler );
+  set_signal( SIGILL, termination_handler );
   set_signal( SIGINT, SIG_IGN );
   set_signal( SIGPIPE, SIG_IGN );
-  set_signal( SIGFPE, SIG_IGN );
-  set_signal( SIGALRM, Screen::clock_handler );
+  set_signal( SIGSEGV, termination_handler );
+  set_signal( SIGTERM, termination_handler );
+  set_signal( SIGUSR1, SIG_IGN );
+  set_signal( SIGUSR2, SIG_IGN );
   }
 
 
