@@ -38,19 +38,18 @@ const char *help_line[] = {
   " ^[V End of file           ^G  Find next            Tab Filename completion",
   " ^[L Line                  ^W  Find word            ^B  Reformat paragraph",
   " ^[C Column                ^QU update (C)           ^P  Control char",
-  " ^[B Beg of block                                   ^Y  Delete line",
-  " ^[K End of block          @bBOOKMARKS@b                ^OC Center line",
-  " ^[F Match pair ->         ^[ 0-9 Goto              ^ON Change buffer name",
-  " ^[G Match pair <-         ^K 0-9 Set               ^OR Repaint screen",
-  " ^[D Center cursor                                  ^OS Split window",
-  "                           @bINFO@b                     ^Q@bF2@b Save named buffers",
-  " @bSCROLL@b                    ^H  Show help",
-  " ^[W Up                    ^SC Show character code",
-  " ^[Z Down                  ^SG Show global status",
-  " ^[A Left                  ^SI Show character info",
-  " ^[S Right                 ^SV Show version",
-  " ",
-  " ^[X means Alt-X or Esc-X    ^X means Control-X",
+  " ^[O Offset                                         ^Y  Delete line",
+  " ^[B Beg of block          @bBOOKMARKS@b                ^OC Center line",
+  " ^[K End of block          ^[ 0-9 Goto              ^ON Change buffer name",
+  " ^[F Match pair ->         ^K 0-9 Set               ^OR Repaint screen",
+  " ^[G Match pair <-                                  ^OS Split window",
+  " ^[D Center cursor         @bINFO@b                     ^Q@bF2@b Save named buffers",
+  "                           ^H  Show help",
+  " @bSCROLL@b                    ^SC Show character code",
+  " ^[W Up                    ^SG Show global status",
+  " ^[Z Down                  ^SI Show character info",
+  " ^[A Left                  ^SV Show version",
+  " ^[S Right",
   "",
   " Help Screen: Block Commands     PAGE_DN next/PAGE_UP prev",
   " ",
@@ -67,6 +66,15 @@ const char *help_line[] = {
   " ^KU Unindent",
   " ^OL To lowercase",
   " ^OU To uppercase",
+  " ",
+  " ",
+  " ",
+  " ",
+  " ",
+  " ",
+  " ",
+  " ",
+  " ^[X means Alt-X or Esc-X    ^X means Control-X",
   "",
   " Help Screen: Search             PAGE_DN next/PAGE_UP prev",
   " ",
