@@ -587,7 +587,7 @@ void Window_vector::reformat() throw()
       }
     if( space ) tmp.pdelc( dummy, true );
     if( dummy != tmp.bol( dummy ) ) tmp.pputc( dummy, '\n' );
-    bool change = ( tmp.eof().line != ( eop.line - bop.line ) );
+    bool change = ( tmp.last_line() != ( eop.line - bop.line ) );
     if( !change )
       for( int line = 0; line < tmp.lines(); ++line )
         if( tmp.characters( line ) != buffer.characters( bop.line + line ) &&
